@@ -432,7 +432,7 @@ int main(int argc, char *argv[])
 
   switch (argc) {
   case 1: f = stdin; break;
-  case 2: if (! (f = fopen(argv[1], "r"))) perror(argv[0]); break;
+  case 2: if (! (f = fopen(argv[1], "r"))) err(EX_NOINPUT,"%s",argv[1]); break;
   default: usage(argv[0]);
   }
   if (! read_EOT_header(f, &header)) errx(1, "Unrecognized EOT header");
